@@ -15,9 +15,11 @@ test_that("Results of 'adjclust' are shifted by lambda when similarity is shifte
 })
 
 test_that("Results of the algorithm are shifted by lambda when similarity is unnormalized and heights are positive", {
-  expect_message(fit3 <- adjClust(sim2), "added")
-  expect_message(fit4 <- adjClust(sim2), fit3$correction)
-
+  msg <- sprintf("added %s to diagonal", "[0-9]+\\.?[0-9]*")
+  expect_message(fit3 <- adjClust(sim2), msg)
+  msg <- sprintf("added %s to diagonal", as.character(fit3$correction))
+  expect_message(fit4 <- adjClust(sim2), msg)
+  
   tmp <- sweep(-2*sim2, 1, diag(sim2), "+")
   tmp <- sweep(tmp, 2, diag(sim2), "+")
   tmp <- tmp[upper.tri(tmp)]
@@ -30,4 +32,4 @@ test_that("Results of the algorithm are shifted by lambda when similarity is unn
 test_that("A message is displayed when 'select' is used on results obtained from preprocessed matrices", {
   suppressMessages({fit3 <- adjClust(sim2)})
   expect_message(adjclust::select(fit3, type = "bstick"), "might be spurious")
-})
\ No newline at end of file
+})
